# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2024-10-16
### Added
- Initial release of the project.

### Changed
- None, as this is the initial release.

### Deprecated
- None, as this is the initial release.

### Removed
- None, as this is the initial release.

### Fixed
- Initial bug fixes prior to release.

